//====================================================================
//Serial Time-Base:
//  Serial port is IUS51 and Vision51 Transmission interface.
//  Timer1 or Timer2(depend on ius_BaudRateUseTimer setting) is used
//  as the UART baud rates generator.
//  To use Timer1 as baud rates generater:
//    For this purpose Timer1 is used in mode 2 (Auto-Reload).
//    Baud Rate = ius_SYSTEM_CLOCK/(iusSTBn*(256-TH1))
//  To use Timer2 as baud rates generator:
//    For this purpose Timer2 is used in Auto-Reload mode.
//    Baud Rate= ius_SYSTEM_CLOCK/(iusSTBn*(65536-RCAP2))
//    The iusSTBn(n can be 0~9) means "Serial Time-Base" thant need
//    defined at here.
//    Also each iusSTBn need define a corresponding iusSETUP_STBn macro.
//    to setup correct Serial Time-Base.
//    For example, the timer 1 of standard 8051 family counting at the
//    rate of 1/12 of the clock frequency.
//    The baud rates formula for serial port in mode 2 is:
//        Baud Rates= (k*ius_SYSTEM_CLOCK)/(32*12*(256-TH1))
//                  = ius_SYSTEM_CLOCK/((32*12/k)*(256-TH1))--->iusSTBn=(32*12/k)
//        Note K= SMOD+1(SMOD is bit 7 of the PCON register)
//        Here we need define two sets of iusSTBn/iusSETUP_STBn: 
//            #define iusSETUP_STB0		PCON &= 0x7F; //SMOD=0
//            #define iusSTB0			(32*12/1)
//            #define iusSETUP_STB1		PCON |= 0x80; //SMOD=1
//            #define iusSTB1			(32*12/2)
//    Macro "iusINIT_SERIAL" also need define here for serial initiation.
//--------------------------------------------------------------------
//Standard 8051 family:
	#if ius_BaudRateUseTimer==1
		//Serial port in MODE 1, Timer 1 used in mode 2 (Auto-Reload)
		#define iusINIT_SERIAL	SCON=0x50, TMOD=((TMOD&0x0F)|0x20);
		//
		#define iusSETUP_STB0	PCON &= 0x7F;
		#define iusSTB0			(32UL*12/1)
		//
		#define iusSETUP_STB1	PCON |= 0x80;
		#define iusSTB1			(32UL*12/2)
	#elif ius_BaudRateUseTimer==2
		//Serial port in MODE 1, Timer 2 used in Auto-Reload mode
		#define iusINIT_SERIAL	SCON=0x50, T2CON=0x30;
		//
		#define iusSETUP_STB0	//do nothing
		#define iusSTB0			32UL
	#endif
